<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":	$messaggio = "Изменить или удалить бронь"; break;
case "Prenotazione a nome di":  		$messaggio = "Бронирование для"; break;
case "nato il":  				$messaggio = "родился "; break;
case "nata il":  				$messaggio = "родился "; break;
case "e":  					$messaggio = "и"; break;
case "CAP":  					$messaggio = "почтовый индекс"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "2º telefono":  				$messaggio = "2-й телефон"; break;
case "3º telefono":  				$messaggio = "3-й телефон"; break;
case "Modifica i dati del cliente":  		$messaggio = "Изменить данные клиента"; break;
case "settimane":  				$messaggio = "неделя(ь)"; break;
case "giorni":  				$messaggio = "сутки(ок)"; break;
case "giorno":  				$messaggio = "day"; break;
case "dal":  					$messaggio = "от"; break;
case "al":  					$messaggio = "до"; break;
case "cambia in":  				$messaggio = "изменить на"; break;
case "in":  					$messaggio = "в"; break;
case "Nº di piano":  				$messaggio = "Этаж"; break;
case "e/o di casa":  				$messaggio = "и/или корпус"; break;
case "e/o di persone":  			$messaggio = "и/или число людей"; break;
case "Nº di persone":  				$messaggio = "Число людей"; break;
case "Commento":  				$messaggio = "Комментарий"; break;
case "Cancella il commento":  			$messaggio = "Удалить комментарий"; break;
case "Tipo di tariffa":  			$messaggio = "Тип цены"; break;
case "tariffa":  				$messaggio = "цена"; break;
case "Sconto":  				$messaggio = "Скидка"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "resto":  					$messaggio = "отдых"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Рассчитать снова депозит с новыми ценами"; break;
case "Costo aggiuntivo unico":  		$messaggio = "Единичный дополнительный расход"; break;
case "moltiplicato per":  			$messaggio = "умножено на"; break;
case "Costo aggiuntivo settimanale":  		$messaggio = "Еженедельные дополнительные расходы"; break;
case "Costo aggiuntivo giornaliero":  		$messaggio = "Ежедневные дополнительные расходы"; break;
case "per":  					$messaggio = "для"; break;
case "settimane moltiplicato per":  		$messaggio = "недели, умноженные на"; break;
case "giorni moltiplicato per":  		$messaggio = "дни, умноженные на"; break;
case "della tariffa moltiplicato per":  	$messaggio = "цен, умноженных на"; break;
case "Prenotazione confermata":  		$messaggio = "Бронь подтверждена"; break;
case "Totale da pagare":  			$messaggio = "Полностью к оплате"; break;
case "Pagato":  				$messaggio = "Оплачено"; break;
case "aggiungi":  				$messaggio = "добавить"; break;
case "pagato tutto":  				$messaggio = "все оплачено"; break;
case "caparra ":  				$messaggio = "депозит оплачен"; break;
case "Ancora da pagare":  			$messaggio = "Все еще к оплате"; break;
case "Nuovo costo aggiuntivo unico":  		$messaggio = "Новый единичный дополнительный расход"; break;
case "di":  					$messaggio = " "; break;
case "da moltiplicare per":  			$messaggio = "чтобы умножить"; break;
case "letto":  					$messaggio = "кровать (место)"; break;
case "straordinario":  				$messaggio = "экстраординарный"; break;
case "Nuovo costo aggiuntivo settimanale":	$messaggio = "Новые еженедельные дополнительные расходы"; break;
case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "Новые ежедневные дополнительные расходы"; break;
case "nº di settimane da applicare":  		$messaggio = "число недель для учета"; break;
case "nº di giorni da applicare":  		$messaggio = "число дней для учета"; break;
case "non specificato":  			$messaggio = "недоступно"; break;
case "Modifica la prenotazione":  		$messaggio = "Изменить бронь"; break;
case "Cancella la prenotazione":  		$messaggio = "Удалить бронь"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "SI":  					$messaggio = "ДА"; break;
case "cancella anche ciò che era stato pagato":	$messaggio = "удалить также то, что было оплачено"; break;
case "NO":  					$messaggio = "НЕТ"; break;
case "La prenotazione":  			$messaggio = "Бронь"; break;
case "Prenotazione":  				$messaggio = "Бронь"; break;
case "cancellata":  				$messaggio = "удалена"; break;
case "<b>non è stata cancellata</b> perchè è stata modificata nel frattempo":	$messaggio = "<b>не была удалена</b>, потому что изменялась в это время"; break;
case "Si è sicuri di voler <b>cancellare</b> la prenotazione":	$messaggio = "Вы уверены в том, что хотите <b>удалить</b> бронь"; break;
case "al":  					$messaggio = "до"; break;
case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":	$messaggio = "<div style=\"display: inline; color: red;\">Эти даты</div> <b>неверны</b>"; break;
case "della casa":  				$messaggio = "от верхних"; break;
case "con massimo numero di occupanti":  	$messaggio = "с максимальным числом размещенных людей"; break;
case "a":  					$messaggio = "на"; break;
case "Il numero delle persone verrà cambiato da":	$messaggio = "Число людей будет изменено с"; break;
case "persone":  				$messaggio = "люди"; break;
case "è stata <b>cancellata</b>":  		$messaggio = "были <b>удалены</b>"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Перемещения должны быть сделаны в периоде <div style=\"display: inline; color: blue;\">правила размещения 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "Бронь с"; break;
case "a nome di":  				$messaggio = "для à -на/à -жи"; break;
case "mantenuta":  				$messaggio = "оставлена"; break;
case "spostata":  				$messaggio = "перемещена"; break;
case "La tariffa":  				$messaggio = "Эта цена"; break;
case "non esiste più, cambiala prima di aggiornare":	$messaggio = "не существует больше, измените перед обновлением"; break;
case "<b>Non</b> è stato ancora inserito il prezzo della":	$messaggio = "Вы должны <b>еще</b> вставить прайс"; break;
case "per la settimana dal":  			$messaggio = "для недели с"; break;
case "per il giorno dal":  			$messaggio = "для дня с"; break;
case "Il costo aggiuntivo":  			$messaggio = "Дополнительные расходы"; break;
case "Il costo aggiuntivo unico":  		$messaggio = "Единичный дополнительный расход"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "Еженедельные дополнительные расходы"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "Ежедневные дополнительные расходы"; break;
case "non può essere moltiplicato per":  	$messaggio = "не могут быть умножены на"; break;
case "prima era":  				$messaggio = "это было"; break;
case "Le settimane del costo aggiuntivo":  	$messaggio = "Недели дополнительных расходов"; break;
case "I giorni del costo aggiuntivo":  		$messaggio = "Дни дополнительных расходов"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "<b>превышают</b> во время брони"; break;
case "verranno cabiate da":  			$messaggio = "будет изменен с"; break;
case "verranno cabiati da":  			$messaggio = "будут изменены с"; break;
case "verranno cabiate":  			$messaggio = "будет изменен"; break;
case "verranno cabiati":  			$messaggio = "будут изменены"; break;
case "<b>non</b> verranno cambiate":  		$messaggio = "<b>не</b> будет изменен"; break;
case "<b>non</b> verranno cambiati":  		$messaggio = "will <b>не</b> будут изменены"; break;
case "su":  					$messaggio = "на"; break;
case "Il prezzo del costo aggiuntivo":  	$messaggio = "Прайс на дополнительные расходы"; break;
case "verrà tolto":  				$messaggio = "будет удален"; break;
case "verrà aggiunto":  			$messaggio = "будет добавлена"; break;
case "come letto aggiuntivo":  			$messaggio = "как дополнительное место"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "Недели новых дополнительных расходов"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "Дни новых дополнительных расходов"; break;
case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":	$messaggio = "Вставленная <div style=\"display: inline; color: red;\">скидка</div>"; break;
case "supera il costo totale senza sconto":  	$messaggio = "больше, чем полная стоимость без скидки"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":	$messaggio = "Вставленный <div style=\"display: inline; color: red;\">депозит</div>"; break;
case "supera il costo totale":  		$messaggio = "больше, чем полная стоимость"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div>":  	$messaggio = "<div style=\"display: inline; color: red;\">Депозит</div>"; break;
case "supera il nuovo costo totale":  		$messaggio = "больше, чем новая полная стоимость"; break;
case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":	$messaggio = "Вставленное <div style=\"display: inline; color: red;\">уплаченная</div> сумма"; break;
case "I soldi pagati verranno cambiati da":  		$messaggio = "Уплаченная сумма будет изменена с"; break;
case "verrà <b>confermata</b>":  			$messaggio = "будет <b>подтверждена</b>"; break;
case "Verrà tolta la <b>conferma</b> alla prenotazione":	$messaggio = "<b>Подтверждение</b> будет удалено из брони"; break;
case "Continua":  				$messaggio = "Продолжить"; break;
case "modificata":  				$messaggio = "изменен"; break;
case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "<b>не был изменен</b>, потому что в это время было сделано бронирование"; break;
case "con costo agg.":  			$messaggio = "с дополнительными расходами"; break;
case "Cliente":  				$messaggio = "Клиент"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Нет периодов в правиле размещения 1, куда можно вставить бронь для пользователя"; break;
case "Prenotazione non confermata":  		$messaggio = "Бронь не подтверждена"; break;
case "Inserita dall'utente":  			$messaggio = "Вставлено пользователем"; break;
case "come colui che ha inserito la prenotazione":	$messaggio = "будет считаться тем, кто вставил эту бронь"; break;
case "Non si possono inserire altri costi":  	$messaggio = "Вы не можете добавить больше стоимостей"; break;
case "presenti":  				$messaggio = "настоящий"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "Дополнительные расходы"; break;
case "in questo periodo":  			$messaggio = "не могут быть добавлены в этот период"; break;
case "Settimane":  				$messaggio = "Недели"; break;
case "Giorni":  				$messaggio = "Дни"; break;
case "mostra":  				$messaggio = "показать"; break;
case "nascondi":  				$messaggio = "скрыть"; break;
case "numeri diversi":  			$messaggio = "различные числа"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "Вы не можете вставить более одного дополнительного расхода с процентом от полной стоимости на одну бронь"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Выберите недели, чтобы добавить дополнительные расходы"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Выберите недели, чтобы добавить дополнительные расходы"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Число людей должно быть вставлено для дополнительных расходов"; break;
case "Non si possono inserire altri costi":  	$messaggio = "Вы не можете добавить больше стоимостей"; break;
case "presenti":  				$messaggio = "настоящий"; break;
case "della tariffa":  				$messaggio = "цены"; break;
case "del totale":  				$messaggio = "полной"; break;
case "della caparra":  				$messaggio = "депозита"; break;
case "del resto caparra":  			$messaggio = "остатка депозита"; break;
case "di base":  				$messaggio = "основной"; break;
case "totale":  				$messaggio = "полный"; break;
case "registra entrata":  			$messaggio = "регистрация"; break;
case "cancella entrata":  			$messaggio = "выход из регистрации"; break;
case "registra uscita":  			$messaggio = "выписка"; break;
case "cancella uscita":  			$messaggio = "выход из выписки"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Предупреждение</div>: не могу осуществить выписку, сделайте сначала регистрацию"; break;
case "Metodo pagamento caparra":  		$messaggio = "Способ оплаты депозита"; break;
case "Metodo di pagamento":  			$messaggio = "Способ оплаты"; break;
case "metodo di pagamento":  			$messaggio = "способ оплаты"; break;
case "Prova di nuovo":  			$messaggio = "Попробуйте снова"; break;
case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "перемещая также бронирования, начатые после"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "несовместимы с выделенными правилами"; break;
case "non può essere applicato":  		$messaggio = "не могут быть применены"; break;
case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "Вы не можете изменить назначение бронирования, которое находится <div style=\"display: inline; color: red;\">между двумя годами</div>"; break;
case "Modifica nell'anno precedente":  		$messaggio = "Изменить в предыдущем году"; break;
case "Orario entrata stimato":  		$messaggio = "Примерное время регистрации"; break;
case "Codice prenotazione":  			$messaggio = "Код бронирования"; break;
case "rigenera":  				$messaggio = "восстановить"; break;
case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":	$messaggio = "Не возможно было переместить бронь по причине регистрации"; break;
case "Cambia cliente":  			$messaggio = "Изменить клиента"; break;
case "Nuovo titolare della prenotazione":	$messaggio = "Новый заголовок бронирования"; break;
case "cliente numero":  			$messaggio = "номер клиента"; break;
case "Il titolare della prenotazione":  	$messaggio = "Заголовок бронирования"; break;
case "Cliente non trovato":  			$messaggio = "Клиент не найден"; break;
case "Annulla":  				$messaggio = "Выход"; break;
case "Prenotazioni vicine":  			$messaggio = "Закрыть брони"; break;
case "numero":  				$messaggio = "номер"; break;
case "La prenotazione numero":  		$messaggio = "Номер брони"; break;
case "non esiste":  				$messaggio = "не существует"; break;
case "Ospiti della prenotazione":  		$messaggio = "Гости бронирования"; break;
case "Modifica gli ospiti":  			$messaggio = "Изменить гостей"; break;
case "nato":  					$messaggio = "родился"; break;
case "nata":  					$messaggio = "родился"; break;
case "il":  					$messaggio = "в"; break;
case " a":  					$messaggio = " в"; break;
case "scade":  					$messaggio = "окончания"; break;
case "Codice fiscale":  			$messaggio = "Финансовый код"; break;
case "Origine":  				$messaggio = "Источник"; break;
case "tutte":  					$messaggio = "all"; break;
case "ln.":  					$messaggio = "ln."; break;
case "id op.":  				$messaggio = "id"; break;
case "Modifica Prenotazioni":  			$messaggio = "Modify reservations"; break;
case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "The reservation is from previus year, you will be able to modify only the final date"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "era già stata cancellata":  		$messaggio = "has already been deleted"; break;
case "Si è sicuri di voler <b>cancellare</b> le prenotazioni":	$messaggio = "Are you sure you want to <b>delete</b> reservations"; break;
case "La data iniziale verrà cambiata dal":  	$messaggio = "The beginning date will be changed from"; break;
case "La data finale verrà cambiata dal":  	$messaggio = "The final date will be changed from"; break;
case "°</b> piano":  				$messaggio = "</b>"; break;
case "La prenotazione verrà":  			$messaggio = "The reservation will be"; break;
case "La tariffa verrà cambiata da":  		$messaggio = "The rate will be changed from"; break;
case "verrà moltiplicato per":  		$messaggio = "will be multiplied by"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":	$messaggio = "Data for the <b>extraordinary</b> extra cost are <div style=\"display: inline; color: red;\">wrong or lacking</div>"; break;
case "Lo sconto verrà cambiato da":  		$messaggio = "The discount will be changed from"; break;
case "La caparra verrà cambiata da":  		$messaggio = "The deposit will be changed from"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>commento</b> verrà cancellato":  	$messaggio = "The <b>comment</b> will be deleted"; break;
case "verrà cambiato da":  			$messaggio = "will be changed from"; break;
case "Si considererà l'utente":  		$messaggio = "User"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in already registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in not registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out already registered"; break;
case "Il metodo di pagamento della caparra verrà cambiato a":	$messaggio = "Deposit payment method will be changed to"; break;
case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normally already begun reservations and the ones that have done check-in are not moved"; break;
case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "considered fixed because <div style=\"display: inline; color: red;\">as of today already begun</div>"; break;
case "L'orario stimato di entrata verrà cambiato a":	$messaggio = "The estimated check-in time will be changed to"; break;
case "Il titolare delle prenotazioni":  	$messaggio = "The titular of reservations"; break;
case "L'origine della prenotazione verrà cambiata a":	$messaggio = "The reservation origin will be changed to"; break;
case "Modifica o cancella le prenotazioni":  	$messaggio = "Modify or delete reservations"; break;
case "Modifica le prenotazioni":  		$messaggio = "Modify reservations"; break;
case "Cancella le prenotazioni":  		$messaggio = "Delete reservations"; break;
case "della prenotazione":  			$messaggio = "from reservation"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "Data inserimento":  			$messaggio = "Insertion date"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
case "pren.":  					$messaggio = "res."; break;
case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "The <span class=\"colred\">number of people</span> must be inserted for the selected rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "items needed by check-in"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Calculate again the commissions from the new rate"; break;
case "Le commissioni verranno cambiate da":	$messaggio = "Commissions will be changed from"; break;
case "tasse":  					$messaggio = "taxes"; break;
case "Il prezzo totale cambierà da":  		$messaggio = "The total price will change from"; break;
case "saldo di":  				$messaggio = "balance"; break;
case "Altre prenotazioni dello stesso cliente nello stesso periodo":	$messaggio = "Other reservations from the same client in the same period"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":	$messaggio = "there are other reservations from the same client in the same period that have not been paid yet"; break;
case "Il saldo totale pagato sarà di":  	$messaggio = "The total balance of money paid will be"; break;
case "della tariffa fissa":  			$messaggio = "of fixed rate"; break;
case "di una persona":  			$messaggio = "of one person"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "Nuovo costo aggiuntivo":  		$messaggio = "New extra cost"; break;
case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
case "cambia il commento":  			$messaggio = "change comment"; break;
case "Il commento":  				$messaggio = "Comment"; break;
case "verrà cambiato":  			$messaggio = "will be changed"; break;
case "per ":  					$messaggio = "for "; break;
case "Il numero di":  				$messaggio = "The number of"; break;
case "Valuta":  				$messaggio = "Currency"; break;
case "Valuta caparra":  			$messaggio = "Deposit currency"; break;
case "Al cambio attuale":  			$messaggio = "At current exchange rate"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "cancella in modo permanente":  		$messaggio = "delete permanently"; break;
case "in modo permanente":  			$messaggio = "permanently"; break;
case "Prenotazione cancellata":  		$messaggio = "Deleted reservation"; break;
case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
case "Data o orario stimato di entrata <span class=\"colred\">errato</span>":	$messaggio = "<span class=\"colred\">Wrong</span> estimated check-in time or date"; break;
case "Data cancellazione":  			$messaggio = "Deletion date"; break;
case "Cancellata dall'utente":  		$messaggio = "Deleted by user"; break;
case "Per la tariffa selezionata si deve inserire un <span class=\"colred\">numero minimo</span> di":	$messaggio = "For selected rate you have to insert a <span class=\"colred\">minimum number</span> of"; break;
case "persona":  				$messaggio = "person"; break;
case "id operazione":  				$messaggio = "transaction id"; break;
case "Data operazione":  			$messaggio = "Transaction date"; break;
case "Data":  					$messaggio = "Date"; break;
case "Note":  					$messaggio = "Notes"; break;
case "Informazioni extra":  			$messaggio = "Extra info"; break;
case "Inserisci una prenotazione uguale":  	$messaggio = "Insert a reservation like this"; break;
case "Inserisci prenotazioni uguali":  		$messaggio = "Insert reservations like these"; break;
case "Cambia il cliente anche nei pagamenti effettuati":	$messaggio = "Change client also in payments already made"; break;
case "Ripristina la prenotazione":  		$messaggio = "Restore reservation"; break;
case "Ripristina le prenotazioni":  		$messaggio = "Restore reservations"; break;
case "Non si possono inserire prenotazioni nel passato":	$messaggio = "You can't insert reservations in the past"; break;
case "Si è sicuri di voler provare a <b>ripristinare</b> la prenotazione":	$messaggio = "Are you sure you want to try <b>restoring</b> the reservation"; break;
case "Si è sicuri di voler provare a <b>ripristinare</b> le prenotazioni":	$messaggio = "Are you sure you want to try <b>restoring</b> reservations"; break;
case "ripristinata":  				$messaggio = "restored"; break;
case "Le date della prenotazione":  		$messaggio = "The reservation dates"; break;
case "non sono attualmente disponibili":  	$messaggio = "are not currently available"; break;
case "sono attualmente chiuse":  		$messaggio = "are currently closed"; break;
case "Le date vanno liberate manualmente prima di poter ripristinare la prenotazione":	$messaggio = "Dates must be manually freed before the reservation can be restored"; break;
case "Le prenotazioni vicine alla prenotazione":	$messaggio = "Reservations nearby reservation"; break;
case "vanno ripristinate manualemnte":  	$messaggio = "must be restored manually"; break;
case "cancellare manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "manually deleting a reservation coming from interconnections"; break;
case "senza aspettare che venga cancellata dall'interconnessione":	$messaggio = "without waiting for it to be deleted by the interconnection"; break;
case "può creare overbooking":  		$messaggio = "may cause overbooking"; break;
case "rimpicciolire manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "manually shrinking a reservation coming from interconnections"; break;
case "senza aspettare che venga modificata dall'interconnessione":	$messaggio = "without waiting for it to be modified by the interconnection"; break;
case "gli altri campi":  			$messaggio = "the other fields"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>